==> emiclock-1.0.4.tar.gz: emiclock-1.0.4/include/const.h <==
/* $Id: const.h,v 1.3 1997/01/11 03:21:03 masa-k Exp $
 *
 *  Emi Clock $B!=(B $BDj?tDj5A(B
 */

/*
 *  Copyright (c) 1994, 1995, 1997 Masayuki Koba.
 *
 *  $BK\%=%U%H%&%'%"$N%=!<%9$d%P%$%J%j$r:FG[I[$9$k>l9g$O!"<!$N>r7o$r=e<i$7$F(B
 *  $B2<$5$$!#(B
 *
 *  1. $BK\%=%U%H%&%'%"$rF~<j$7$?J}$K$O!"(BX11$BHG(B Emi Clock $B$N;HMQ8"$H!"Bh;0<T(B
 *     $B$X$N:FG[I[8"$,G'$a$i$l$^$9!#$?$@$7!":FG[I[$K4X$7$F$O!"F~<j;~$N%*%j(B
 *     $B%8%J%k$N$^$^2~JQ$;$:$K9T$&$3$H$,>r7o$G$9!#(B
 *  2. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$G2~JQ$7$FG[I[$9$k$3(B
 *     $B$H$O$G$-$^$;$s!#(B
 *  3. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$GFs<!MxMQ$9$k$3$H$O(B
 *     $B$G$-$^$;$s!#(B
 *  4. $BK\%=%U%H%&%'%"$r%7%9%F%`$K%P%s%I%k$7$?$j!"%7%9%F%`$NDI2C%Q%C%1!<%8(B
 *     $B$H$7$FBh;0<T$K:FG[I[$7$?$j$9$k>l9g$O!";vA0$KCx:n8"<T$K5v2D$,I,MW$G(B
 *     $B$9!#(B
 *  5. $BK\%=%U%H%&%'%"$r>&MQ$K;HMQ$9$k>l9g(B($B6bA,E*Mx1W$rF@$k>l9g(B)$B$O!";vA0$K(B
 *     $BCx:n8"<T$K5v2D$,I,MW$G$9!#$3$N>l9g!"4pK\E*$KM-=~$H$J$j$^$9!#(B
 *  6. $BK\%=%U%H%&%'%"$rMxMQ$9$k$3$H$K$h$C$FH/@8$7$?$$$+$J$kB;32$b!"Cx:n8"(B
 *     $B<T$OIi$o$J$$$b$N$H$7$^$9!#$3$l$K9g0U$G$-$J$$>l9g$O!";HMQ8"$,$J$$$b(B
 *     $B$N$H$7$^$9!#(B
 *  7. $B!H(BEmi Clock$B!I$N>&I8$*$h$SK\%=%U%H%&%'%"$N2hA|$d%G%6%$%s$K4X$9$kCx:n(B
 *     $B8"$O!"(BMotosoft $B$3$H!HK\(B $B=SLi!I;a$,M-$7$^$9!#(B
 *  8. $B!H(BEmi Clock$B!I$N>&I8$*$h$S2hA|$d%G%6%$%s$O!"(BX11$BHG(B Emi Clock $B3+H/$N$?(B
 *     $B$a!"(BMotosoft $B$h$j!H8E>l(B $B@59T!I$X8D?ME*$K%i%$%;%s%96!M?$5$l$F$^$9!#(B
 *     $BBh;0<T$XFs<!%i%$%;%s%96!M?$9$k$3$H$OG'$a$i$l$F$*$j$^$;$s!#(B
 *  9. Motosoft $B$H8E>l$KL5CG$G!"K\%=%U%H%&%'%"$N2hA|%G!<%?$rFs<!MxMQ$9$k$3(B
 *     $B$H$r6X;_$7$^$9!#(B
 * 10. $B$3$3$K5-=R$7$?0J30$N8"Mx$K$D$$$F$O!"F|K\9q$NCx:n8"K!$K$h$k$b$N$H$7(B
 *     $B$^$9!#(B
 */

#ifndef	_EMI_CONST_H_
#define	_EMI_CONST_H_

#ifndef	NULL
#define	NULL		0
#endif	/* !NULL */

#ifndef	MAXPATHLEN
#define	MAXPATHLEN	1024
#endif	/* !MAXPATHLEN */

#define	CBASE_WIDTH	131			/* $BJ8;zHW$NI}(B */
#define	CBASE_HEIGHT	131			/* $BJ8;zHW$N9b$5(B */
#define	NUM_OF_CBASE	2			/* $BJ8;zHW$N?t(B */

#define	CHAR_WIDTH	40			/* $B%-%c%i%/%?$NI}(B */
#define	CHAR_HEIGHT	61			/* $B%-%c%i%/%?$N9b$5(B */
#define	NUM_OF_CHAR	20			/* $B%-%c%i%/%?$N?t(B */

#define	TIMER_R	((CBASE_WIDTH / 2) - 20)	/* $BCf$NJ}$NJ8;zHW$NH>7B(B */

#ifndef	M_PI
#define	M_PI		3.14159265358979323846	/* $B&P(B */
#endif	/* !M_PI */

#ifndef	M_PI_2
#define	M_PI_2		1.57079632679489661923	/* $B&P(B/2 */
#endif	/* !M_PI_2 */

#define	PIXELS_8	256	/* 8 plane (256$B?'(B) $B%5!<%P!<$N%+%i!<%;%k$N?t(B */

/* $B%P!<%8%g%sJ8;zNs$r@8@.$9$k$N$K==J,$J%P%$%H?t(B */
#define	VERSION_STR_LEN	256

#define	FIX_STR		"Rel"		/* $B%j%j!<%9(B FIX $B;~$NJ8;zNs(B */
#define	NOSSOUND_STR	"-nossound"	/* $B5/F02;$J$7$N%*%W%7%g%sJ8;zNs(B */
#define	HELP_STR	"-help"		/* Usage $BI=<(%*%W%7%g%sJ8;zNs(B */
#define	VERS_STR	"-ver"		/* $B%P!<%8%g%sI=<(%*%W%7%g%sJ8;zNs(B */

/* $B%a%$%s%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	OPTION_STR		"option"
#define	CHIME_STR		"chime"
#define	COSTUMES_STR		"costumes"
#define	FACE_STR		"face"
#define	ABOUT_STR		"about"
#define	EXIT_STR		"exit"

#define	LINE_STR		"line"	/* $B%a%K%e!<$N(B($B@~(B)$B$r0UL#$9$kJ8;zNs(B */

/* $B!H%*%W%7%g%s!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	DISPLAY_SEC_STR		"displaySecond"
#define	STARTUP_SOUND_STR	"startupSound"

/* $B!H%A%c%$%`!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	HOURKY_CHIME_STR	"hourlyChime"
#define	HALF_HOUR_CHIME_STR	"halfHourChime"
#define	NOTE_ALARM_STR		"noteAlarm"
#define	ALARM_SETTINGS_STR	"alarmSettings"

/* $B!HCe$;BX$(!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	COSTUME_BASE_STR	"costume"
#define	HOURLY_CHAR_CHANGE_STR	"hourlyCharChange"

/* $BCe$;BX$(%$%s%9%?%s%9J8;zNs$r@8@.$9$k$N$K==J,$J%P%$%H?t(B */
#define	COSTUME_STR_LEN		128

/* $B!HJ8;zHW!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	PICTURE_STR		"picture"
#define	NUMBER_STR		"number"

/* XFreeColors() $B$7$F$O$$$1$J$$%T%/%;%k$rI=$9CM(B */
#define	SPECIAL_PIXEL		-999

/* $B%5%&%s%I4X78$NDj?t(B */
#define	SOUND_NO_ERROR		0
#define	SOUND_FILE_INVALID	1
#define	SOUND_OPEN_ERROR	2
#define	SOUND_DEVICE_BUSY	3
#define	SOUND_NO_DEVICE		4
#define	SOUND_DEVICE_ERROR	5
#define	SOUND_NOT_AVAILABLE	6

#define	CREDIT_WIDTH		225	/* $B%/%l%8%C%H2hA|$NI}(B */
#define	CREDIT_HEIGHT		285	/* $B%/%l%8%C%H2hA|$N9b$5(B */

#define	NUM_OF_CREDIT		4	/* $B%/%l%8%C%H2hA|$N?t(B */

#define	SQUEEZE_SIZE_1		(3.0 / 5.0)	/* $B2#J}8~05=LHf(B(1) */
#define	SQUEEZE_SIZE_2		(1.0 / 5.0)	/* $B2#J}8~05=LHf(B(2) */

/* $B>uBV$rJ]B8$9$k%U%!%$%k$NL>>N(B */
#define	RC_FILE			".emiclockrc"

/* $B%P!<%8%g%sI=<(;~$K=P$F$/$k%a%C%;!<%8(B */
#define	PRODUCT_STR		"Emi Clock"
#define	COPYRIGHT_STR		"Copyright (c) 1994, 1995, 1997 Masayuki Koba."

/* $HOME/.emiclockrc $B$G07$&J8;zNs(B */
#define	RC_COMMENT			"#"
#define	RC_TRUE				"True"
#define	RC_FALSE			"False"
#define	RC_IS_NO_SECOND			"IsNoSecond:"
#define	RC_IS_NO_STARTUP_SOUND		"IsNoStartupSound:"
#define	RC_IS_HOURLY_CHAR_CHANGE	"IsHourlyCharChange:"
#define	RC_CHAR_NO			"CharNo:"
#define	RC_CBASE_NO			"CbaseNo:"
#define	RC_IS_HOURLY_CHIME		"IsHourlyChime:"
#define	RC_IS_HALF_HOUR_CHIME		"IsHalfHourChime:"
#define	RC_IS_PLAY_ALARM		"IsPlayAlarm:"
#define	RC_HOURLY_CHIME_FILE_NAME	"HourlyChimeFileName:"
#define	RC_HALF_HOUR_CHIME_FILE_NAME	"HalfHourChimeFileName:"
#define	RC_ALARM_FILE_NAME		"AlarmFileName:"
#define	RC_ALATM_TIME			"AlarmTime:"
#define	RC_ALATM_DATE			"AlarmDate:"
#define	RC_IS_ONE_TIME			"IsOneTime:"
#define	RC_IS_DAILY_ALARM		"IsDailyAlarm:"

/* $B%H!<%/%s(B */
#define	TOKEN_EOF			1
#define	TOKEN_NEWLINE			2
#define	TOKEN_COMMENT			3
#define	TOKEN_DIGIT			4
#define	TOKEN_TRUE			5
#define	TOKEN_FALSE			6
#define	TOKEN_IS_NO_SECOND		7
#define	TOKEN_IS_NO_STARTUP_SOUND	8
#define	TOKEN_IS_HOURLY_CHAR_CHANGE	9
#define	TOKEN_CHAR_NO			10
#define	TOKEN_CBASE_NO			11
#define	TOKEN_IS_HOURLY_CHIME		12
#define	TOKEN_IS_HALF_HOUR_CHIME	13
#define	TOKEN_IS_PLAY_ALARM		14
#define	TOKEN_HOURLY_CHIME_FILE_NAME	15
#define	TOKEN_HALF_HOUR_CHIME_FILE_NAME	16
#define	TOKEN_ALARM_FILE_NAME		17
#define	TOKEN_ALATM_TIME		18
#define	TOKEN_ALATM_DATE		19
#define	TOKEN_IS_ONE_TIME		20
#define	TOKEN_IS_DAILY_ALARM		21
#define	TOKEN_UNKNOWN			-1

#endif	/* !_EMI_CONST_H_ */

==> emiclock-2.0.2.tar.gz: emiclock-2.0.2/include/const.h <==
/* $Id: const.h,v 1.4 1999/09/26 16:18:21 koba Exp $
 *
 *  Emi Clock $B!=(B $BDj?tDj5A(B
 */

/*
 *  Copyright (c) 1994, 1995, 1997, 1999 Masayuki Koba
 *
 *  $BK\%=%U%H%&%'%"$N%=!<%9$d%P%$%J%j$r:FG[I[$9$k>l9g$O!"<!$N>r7o$r=e<i$7$F(B
 *  $B2<$5$$!#(B
 *
 *  1. $BK\%=%U%H%&%'%"$rF~<j$7$?J}$K$O!"(BX11$BHG(B Emi Clock $B$N;HMQ8"$H!"Bh;0<T(B
 *     $B$X$N:FG[I[8"$,G'$a$i$l$^$9!#$?$@$7!":FG[I[$K4X$7$F$O!"F~<j;~$N%*%j(B
 *     $B%8%J%k$N$^$^2~JQ$;$:$K9T$&$3$H$,>r7o$G$9!#(B
 *  2. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$G2~JQ$7$FG[I[$9$k$3(B
 *     $B$H$O$G$-$^$;$s!#(B
 *  3. $BK\%=%U%H%&%'%"$N0lIt$^$?$OA4It$rCx:n8"<T$KL5CG$GFs<!MxMQ$9$k$3$H$O(B
 *     $B$G$-$^$;$s!#(B
 *  4. $BK\%=%U%H%&%'%"$r%7%9%F%`$K%P%s%I%k$7$?$j!"%7%9%F%`$NDI2C%Q%C%1!<%8(B
 *     $B$H$7$FBh;0<T$K:FG[I[$7$?$j$9$k>l9g$O!";vA0$KCx:n8"<T$K5v2D$,I,MW$G(B
 *     $B$9!#(B
 *  5. $BK\%=%U%H%&%'%"$r>&MQ$K;HMQ$9$k>l9g(B($B6bA,E*Mx1W$rF@$k>l9g(B)$B$O!";vA0$K(B
 *     $BCx:n8"<T$K5v2D$,I,MW$G$9!#$3$N>l9g!"4pK\E*$KM-=~$H$J$j$^$9!#(B
 *  6. $BK\%=%U%H%&%'%"$rMxMQ$9$k$3$H$K$h$C$FH/@8$7$?$$$+$J$kB;32$b!"Cx:n8"(B
 *     $B<T$OIi$o$J$$$b$N$H$7$^$9!#$3$l$K9g0U$G$-$J$$>l9g$O!";HMQ8"$,$J$$$b(B
 *     $B$N$H$7$^$9!#(B
 *  7. $B!H(BEmi Clock$B!I$N>&I8$*$h$SK\%=%U%H%&%'%"$N2hA|$d%G%6%$%s$K4X$9$kCx:n(B
 *     $B8"$O!"(BMotosoft $B$3$H!HK\(B $B=SLi!I;a$,M-$7$^$9!#(B
 *  8. $B!H(BEmi Clock$B!I$N>&I8$*$h$S2hA|$d%G%6%$%s$O!"(BX11$BHG(B Emi Clock $B3+H/$N$?(B
 *     $B$a!"(BMotosoft $B$h$j!H8E>l(B $B@59T!I$X8D?ME*$K%i%$%;%s%96!M?$5$l$F$^$9!#(B
 *     $BBh;0<T$XFs<!%i%$%;%s%96!M?$9$k$3$H$OG'$a$i$l$F$*$j$^$;$s!#(B
 *  9. Motosoft $B$H8E>l$KL5CG$G!"K\%=%U%H%&%'%"$N2hA|%G!<%?$rFs<!MxMQ$9$k$3(B
 *     $B$H$r6X;_$7$^$9!#(B
 * 10. $B$3$3$K5-=R$7$?0J30$N8"Mx$K$D$$$F$O!"F|K\9q$NCx:n8"K!$K$h$k$b$N$H$7(B
 *     $B$^$9!#(B
 */

#ifndef	_EMI_CONST_H_
#define	_EMI_CONST_H_

#ifndef	NULL
#define	NULL		0
#endif	/* !NULL */

#ifndef	MAXPATHLEN
#define	MAXPATHLEN	1024
#endif	/* !MAXPATHLEN */

#define	CBASE_WIDTH	131			/* $BJ8;zHW$NI}(B */
#define	CBASE_HEIGHT	131			/* $BJ8;zHW$N9b$5(B */
#define	NUM_OF_CBASE	3			/* $BJ8;zHW$N?t(B */
#define	CBASE_REVERSE	2			/* $B5U2sE>;~7W$N%$%s%G%C%/%9(B */

#define	CHAR_WIDTH	40			/* $B%-%c%i%/%?$NI}(B */
#define	CHAR_HEIGHT	61			/* $B%-%c%i%/%?$N9b$5(B */
#define	NUM_OF_CHAR	21			/* $B%-%c%i%/%?$N?t(B */

#define	TIMER_R	((CBASE_WIDTH / 2) - 20)	/* $BCf$NJ}$NJ8;zHW$NH>7B(B */

#ifndef	M_PI
#define	M_PI		3.14159265358979323846	/* $B&P(B */
#endif	/* !M_PI */

#ifndef	M_PI_2
#define	M_PI_2		1.57079632679489661923	/* $B&P(B/2 */
#endif	/* !M_PI_2 */

#define	PIXELS_8	256	/* 8 plane (256$B?'(B) $B%5!<%P!<$N%+%i!<%;%k$N?t(B */

/* $B%P!<%8%g%sJ8;zNs$r@8@.$9$k$N$K==J,$J%P%$%H?t(B */
#define	VERSION_STR_LEN	256

#define	NOSSOUND_STR	"-nossound"	/* $B5/F02;$J$7$N%*%W%7%g%sJ8;zNs(B */
#define	HELP_STR	"-help"		/* Usage $BI=<(%*%W%7%g%sJ8;zNs(B */
#define	VERS_STR	"-ver"		/* $B%P!<%8%g%sI=<(%*%W%7%g%sJ8;zNs(B */

/* $B%a%$%s%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	OPTION_STR		"option"
#define	CHIME_STR		"chime"
#define	COSTUMES_STR		"costumes"
#define	FACE_STR		"face"
#define	ABOUT_STR		"about"
#define	EXIT_STR		"exit"

#define	LINE_STR		"line"	/* $B%a%K%e!<$N(B($B@~(B)$B$r0UL#$9$kJ8;zNs(B */

/* $B!H%*%W%7%g%s!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	DISPLAY_SEC_STR		"displaySecond"
#define	STARTUP_SOUND_STR	"startupSound"

/* $B!H%A%c%$%`!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	HOURKY_CHIME_STR	"hourlyChime"
#define	HALF_HOUR_CHIME_STR	"halfHourChime"
#define	NOTE_ALARM_STR		"noteAlarm"
#define	ALARM_SETTINGS_STR	"alarmSettings"

/* $B!HCe$;BX$(!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	COSTUME_BASE_STR	"costume"
#define	HOURLY_CHAR_CHANGE_STR	"hourlyCharChange"
#define	ANIMATE_CHARACTER_STR	"animateCharacter"

/* $BCe$;BX$(%$%s%9%?%s%9J8;zNs$r@8@.$9$k$N$K==J,$J%P%$%H?t(B */
#define	COSTUME_STR_LEN		128

/* $B!HJ8;zHW!I%5%V%a%K%e!<$G;HMQ$7$F$$$k%$%s%9%?%s%9J8;zNs(B */
#define	PICTURE_STR		"picture"
#define	NUMBER_STR		"number"
#define	REVERSE_STR		"reverse"

/* XFreeColors() $B$7$F$O$$$1$J$$%T%/%;%k$rI=$9CM(B */
#define	SPECIAL_PIXEL		-999

/* $B%5%&%s%I4X78$NDj?t(B */
#define	SOUND_NO_ERROR		0
#define	SOUND_FILE_INVALID	1
#define	SOUND_OPEN_ERROR	2
#define	SOUND_DEVICE_BUSY	3
#define	SOUND_NO_DEVICE		4
#define	SOUND_DEVICE_ERROR	5
#define	SOUND_NOT_AVAILABLE	6

#define	CREDIT_WIDTH		225	/* $B%/%l%8%C%H2hA|$NI}(B */
#define	CREDIT_HEIGHT		285	/* $B%/%l%8%C%H2hA|$N9b$5(B */

#define	NUM_OF_CREDIT		4	/* $B%/%l%8%C%H2hA|$N?t(B */

#define	SQUEEZE_SIZE_1		(3.0 / 5.0)	/* $B2#J}8~05=LHf(B(1) */
#define	SQUEEZE_SIZE_2		(1.0 / 5.0)	/* $B2#J}8~05=LHf(B(2) */

/* $B>uBV$rJ]B8$9$k%U%!%$%k$NL>>N(B */
#define	RC_FILE			".emiclockrc"

/* $B%P!<%8%g%sI=<(;~$K=P$F$/$k%a%C%;!<%8(B */
#define	PRODUCT_STR	"Emi Clock for X11"
#define	COPYRIGHT_STR	"Copyright (c) 1994, 1995, 1997, 1999 Masayuki Koba"

/* $HOME/.emiclockrc $B$G07$&J8;zNs(B */
#define	RC_COMMENT			"#"
#define	RC_TRUE				"True"
#define	RC_FALSE			"False"
#define	RC_IS_NO_SECOND			"IsNoSecond:"
#define	RC_IS_NO_STARTUP_SOUND		"IsNoStartupSound:"
#define	RC_IS_HOURLY_CHAR_CHANGE	"IsHourlyCharChange:"
#define	RC_IS_ANIMATE_CHARCTER		"IsAnimateCharacter:"
#define	RC_CHAR_NO			"CharNo:"
#define	RC_CBASE_NO			"CbaseNo:"
#define	RC_IS_HOURLY_CHIME		"IsHourlyChime:"
#define	RC_IS_HALF_HOUR_CHIME		"IsHalfHourChime:"
#define	RC_IS_PLAY_ALARM		"IsPlayAlarm:"
#define	RC_HOURLY_CHIME_FILE_NAME	"HourlyChimeFileName:"
#define	RC_HALF_HOUR_CHIME_FILE_NAME	"HalfHourChimeFileName:"
#define	RC_ALARM_FILE_NAME		"AlarmFileName:"
#define	RC_ALATM_TIME			"AlarmTime:"
#define	RC_ALATM_DATE			"AlarmDate:"
#define	RC_IS_ONE_TIME			"IsOneTime:"
#define	RC_IS_DAILY_ALARM		"IsDailyAlarm:"

/* $B%H!<%/%s(B */
#define	TOKEN_EOF			1
#define	TOKEN_NEWLINE			2
#define	TOKEN_COMMENT			3
#define	TOKEN_DIGIT			4
#define	TOKEN_TRUE			5
#define	TOKEN_FALSE			6
#define	TOKEN_IS_NO_SECOND		7
#define	TOKEN_IS_NO_STARTUP_SOUND	8
#define	TOKEN_IS_HOURLY_CHAR_CHANGE	9
#define	TOKEN_IS_ANIMATE_CHARCTER	10
#define	TOKEN_CHAR_NO			11
#define	TOKEN_CBASE_NO			12
#define	TOKEN_IS_HOURLY_CHIME		13
#define	TOKEN_IS_HALF_HOUR_CHIME	14
#define	TOKEN_IS_PLAY_ALARM		15
#define	TOKEN_HOURLY_CHIME_FILE_NAME	16
#define	TOKEN_HALF_HOUR_CHIME_FILE_NAME	17
#define	TOKEN_ALARM_FILE_NAME		18
#define	TOKEN_ALATM_TIME		19
#define	TOKEN_ALATM_DATE		20
#define	TOKEN_IS_ONE_TIME		21
#define	TOKEN_IS_DAILY_ALARM		22
#define	TOKEN_UNKNOWN			-1

#endif	/* !_EMI_CONST_H_ */
